<?php

namespace Drupal\futurama_generate\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\Node;
use Drupal\node\Entity\NodeType;

class FuturamaGenerateForm extends FormBase {

  /**
   * {@inheritdoc}
   * @return string
   */
  public function getFormId() {
    return 'futurama_generate_settings_form';
  }

  /**
   * {@inheritdoc}
   * @return array
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['types'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Content Types'),
      '#options' => $this->getContentTypes(),
    ];
    $form['count'] = [
      '#type' => 'number',
      '#title' => $this->t('How many nodes would you like to generate?'),
      '#default_value' => 50,
      '#required' => TRUE,
    ];
    $form['delete'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Would you like to delete nodes first?')
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Generate'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state); // TODO: Change the autogenerated stub
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $count = $form_state->getValue('count');
    if (!empty($form_state->getValue('delete'))) {
      $batch = [
        'title' => $this->t('Deleting nodes'),
        'init_message' => $this->t('Processing'),
        'operations' => [],
        'progress_message' => $this->t('Processed @current out of @total.'),
        'error_message' => $this->t('An error occurred while processing'),
        'finished' => '\Drupal\futurama_generate\Controller\FuturamaDeleteController::BatchFinished',
      ];
      $nodes = Node::loadMultiple();
      foreach ($nodes as $node) {
        $batch['operations'][] = ['\Drupal\futurama_generate\Controller\FuturamaDeleteController::DeleteContent', [$node]];
      }
      batch_set($batch);
    }
    $batch = [
      'title' => $this->t('Generating nodes'),
      'init_message' => $this->t('Processing'),
      'operations' => [],
      'progress_message' => $this->t('Processed @current out of @total.'),
      'error_message' => $this->t('An error occurred while processing'),
      'finished' => '\Drupal\futurama_generate\Controller\FuturamaGenerateController::BatchFinished',
    ];
    for($i = 0;$i < $count;$i++) {
      $content = [];
      $batch['operations'][] = ['\Drupal\futurama_generate\Controller\FuturamaGenerateController::GenerateContent', [$content]];
    }
    batch_set($batch);
  }

  /**
   * The method to get content types.
   * @return array
   */
  public function getContentTypes() {
    $types = [];
    $content_types = NodeType::loadMultiple();
    foreach ($content_types as $content_type) {
      $types[$content_type->id()] = $content_type->label();
    }
    return $types;
  }
}
